Django REST Search
==================

.. image:: https://img.shields.io/travis/wemap/django-rest-search.svg
    :target: https://travis-ci.org/wemap/django-rest-search

.. image:: https://img.shields.io/coveralls/wemap/django-rest-search.svg
    :target: https://coveralls.io/github/wemap/django-rest-search

.. image:: https://img.shields.io/pypi/v/djangorestsearch.svg
    :target: https://pypi.python.org/pypi/djangorestsearch

Django REST Search provides a set of classes to facilitate the integration of
ElasticSearch into applications powered by the Django REST Framework.

Full documentation for the project is available at
http://django-rest-search.readthedocs.io/.
